@@ -7,6 +7,12 @@ https://github.com/zmathew/django-linguo
 """
 import itertools
 
+import django
+try:
+    from django.contrib.admin.utils import get_model_from_relation
+except ImportError:
+    from django.contrib.admin.util import get_model_from_relation
+
 from django.db import models
 from django.db.models import FieldDoesNotExist
 try:
@@ -48,25 +54,28 @@ def get_translatable_fields_for_model(model):
 
 
 def rewrite_lookup_key(model, lookup_key):
-    pieces = lookup_key.split('__', 1)
-    original_key = pieces[0]
+    try:
+        pieces = lookup_key.split('__', 1)
+        original_key = pieces[0]
 
-    translatable_fields = get_translatable_fields_for_model(model)
-    if translatable_fields is not None:
-        # If we are doing a lookup on a translatable field,
-        # we want to rewrite it to the actual field name
-        # For example, we want to rewrite "name__startswith" to "name_fr__startswith"
-        if pieces[0] in translatable_fields:
-            pieces[0] = build_localized_fieldname(pieces[0], get_language())
+        translatable_fields = get_translatable_fields_for_model(model)
+        if translatable_fields is not None:
+            # If we are doing a lookup on a translatable field,
+            # we want to rewrite it to the actual field name
+            # For example, we want to rewrite "name__startswith" to "name_fr__startswith"
+            if pieces[0] in translatable_fields:
+                pieces[0] = build_localized_fieldname(pieces[0], get_language())
 
-    if len(pieces) > 1:
-        # Check if we are doing a lookup to a related trans model
-        fields_to_trans_models = get_fields_to_translatable_models(model)
-        # Check ``original key``, as pieces[0] may have been already rewritten.
-        if original_key in fields_to_trans_models:
-            transmodel = fields_to_trans_models[original_key]
-            pieces[1] = rewrite_lookup_key(transmodel, pieces[1])
-    return '__'.join(pieces)
+        if len(pieces) > 1:
+            # Check if we are doing a lookup to a related trans model
+            fields_to_trans_models = get_fields_to_translatable_models(model)
+            # Check ``original key``, as pieces[0] may have been already rewritten.
+            if original_key in fields_to_trans_models:
+                transmodel = fields_to_trans_models[original_key]
+                pieces[1] = rewrite_lookup_key(transmodel, pieces[1])
+        return '__'.join(pieces)
+    except AttributeError:
+        return lookup_key
 
 
 def append_fallback(model, fields):
@@ -117,14 +126,25 @@ def append_lookup_key(model, lookup_key):
 
 
 def append_lookup_keys(model, fields):
-    return moves.reduce(set.union, (append_lookup_key(model, field) for field in fields), set())
+    new_fields = []
+    for field in fields:
+        try:
+            new_field = append_lookup_key(model, field)
+        except AttributeError:
+            new_field = (field,)
+        new_fields.append(new_field)
+
+    return moves.reduce(set.union, new_fields, set())
 
 
 def rewrite_order_lookup_key(model, lookup_key):
-    if lookup_key.startswith('-'):
-        return '-' + rewrite_lookup_key(model, lookup_key[1:])
-    else:
-        return rewrite_lookup_key(model, lookup_key)
+    try:
+        if lookup_key.startswith('-'):
+            return '-' + rewrite_lookup_key(model, lookup_key[1:])
+        else:
+            return rewrite_lookup_key(model, lookup_key)
+    except AttributeError:
+        return lookup_key
 
 _F2TM_CACHE = {}
 
@@ -141,8 +161,9 @@ def get_fields_to_translatable_models(model):
                 # In that case the 'related_model' attribute is set to None
                 # so it is necessary to check for this value before trying to
                 # get translatable fields.
-                if get_translatable_fields_for_model(f.related_model) is not None:
-                    results.append((f.name, f.related_model))
+                related_model = get_model_from_relation(f)
+                if get_translatable_fields_for_model(related_model) is not None:
+                    results.append((f.name, related_model))
     else:
         for field_name in model._meta.get_all_field_names():
             field_object, modelclass, direct, m2m = model._meta.get_field_by_name(field_name)
@@ -254,7 +275,10 @@ class MultilingualQuerySet(models.query.QuerySet):
         # new_args = append_lookup_keys(self.model, fields)
         new_args = []
         for key in fields:
-            new_args.append(rewrite_lookup_key(self.model, key))
+            if key is None:
+                new_args.append(None)
+            else:
+                new_args.append(rewrite_lookup_key(self.model, key))
         return super(MultilingualQuerySet, self).select_related(*new_args, **kwargs)
 
     # This method was not present in django-linguo
@@ -543,13 +567,6 @@ else:
             return clone
 
 
-def get_queryset(obj):
-    if hasattr(obj, 'get_queryset'):
-        return obj.get_queryset()
-    else:  # Django 1.4 / 1.5 compat
-        return obj.get_query_set()
-
-
 def multilingual_queryset_factory(old_cls, instantiate=True):
     if old_cls == models.query.QuerySet:
         NewClass = MultilingualQuerySet
@@ -566,7 +583,7 @@ class MultilingualQuerysetManager(models.Manager):
     get_queryset returns MultilingualQuerySet.
     """
     def get_queryset(self):
-        qs = get_queryset(super(MultilingualQuerysetManager, self))
+        qs = super(MultilingualQuerysetManager, self).get_queryset()
         return self._patch_queryset(qs)
 
     def _patch_queryset(self, qs):
@@ -575,11 +592,10 @@ class MultilingualQuerysetManager(models.Manager):
         qs._rewrite_applied_operations()
         return qs
 
-    get_query_set = get_queryset
-
 
 class MultilingualManager(MultilingualQuerysetManager):
-    use_for_related_fields = True
+    if django.VERSION < (1, 10):
+        use_for_related_fields = True
 
     def rewrite(self, *args, **kwargs):
         return self.get_queryset().rewrite(*args, **kwargs)
@@ -595,11 +611,9 @@ class MultilingualManager(MultilingualQuerysetManager):
         This method is repeated because some managers that don't use super() or alter queryset class
         may return queryset that is not subclass of MultilingualQuerySet.
         """
-        qs = get_queryset(super(MultilingualManager, self))
+        qs = super(MultilingualManager, self).get_queryset()
         if isinstance(qs, MultilingualQuerySet):
             # Is already patched by MultilingualQuerysetManager - in most of the cases
             # when custom managers use super() properly in get_queryset.
             return qs
         return self._patch_queryset(qs)
-
-    get_query_set = get_queryset
