@@ -194,8 +194,12 @@ def add_manager(model):
         else:
             class NewMultilingualManager(MultilingualManager, manager.__class__,
                                          MultilingualQuerysetManager):
-                use_for_related_fields = getattr(
-                    manager.__class__, "use_for_related_fields", not has_custom_queryset(manager))
+                if VERSION < (1, 10):
+                    use_for_related_fields = getattr(
+                        manager.__class__,
+                        "use_for_related_fields",
+                        not has_custom_queryset(manager),
+                    )
                 _old_module = manager.__module__
                 _old_class = manager.__class__.__name__
 
@@ -210,9 +214,24 @@ def add_manager(model):
 
             manager.__class__ = NewMultilingualManager
 
-    managers = (model._meta.local_managers if NEW_MANAGER_API else
-                (getattr(model, x[1]) for x in
-                 model._meta.concrete_managers + model._meta.abstract_managers))
+    if NEW_MANAGER_API:
+        # Inspired by django.db.models.options.Options.managers (find all
+        # managers by following the normal Python MRO rules), but keeps the
+        # original managers instead of making copies.
+        managers = []
+        seen = set()
+        bases = (b for b in model.mro() if hasattr(b, '_meta'))
+        for base in bases:
+            for manager in base._meta.local_managers:
+                if manager.name in seen:
+                    continue
+                managers.append(manager)
+                seen.add(manager.name)
+
+    else:
+        managers = ((getattr(model, x[1]) for x in
+                     model._meta.concrete_managers + model._meta.abstract_managers))
+
     for current_manager in managers:
         prev_class = current_manager.__class__
         patch_manager_class(current_manager)
@@ -224,6 +243,8 @@ def add_manager(model):
             # share the same class.
             model._default_manager.__class__ = current_manager.__class__
     patch_manager_class(model._base_manager)
+    if VERSION >= (1, 10):
+        model._meta.base_manager_name = 'objects'
     if hasattr(model._meta, "_expire_cache"):
         model._meta._expire_cache()
 
@@ -529,11 +550,11 @@ class Translator(object):
 
                 # Set related field names on other model
                 if NEW_RELATED_API and not field.remote_field.is_hidden():
-                    other_opts = self._get_options_for_model(field.remote_field.to)
+                    other_opts = self._get_options_for_model(field.remote_field.model)
                     other_opts.related = True
                     other_opts.related_fields.append(field.related_query_name())
                     # Add manager in case of non-registered model
-                    add_manager(field.remote_field.to)
+                    add_manager(field.remote_field.model)
                 elif not NEW_RELATED_API and not field.rel.is_hidden():
                     other_opts = self._get_options_for_model(field.rel.to)
                     other_opts.related = True
@@ -543,7 +564,7 @@ class Translator(object):
             if isinstance(field, OneToOneField):
                 # Fix translated_field caching for SingleRelatedObjectDescriptor
                 sro_descriptor = (
-                    getattr(field.remote_field.to, field.remote_field.get_accessor_name())
+                    getattr(field.remote_field.model, field.remote_field.get_accessor_name())
                     if NEW_RELATED_API
                     else getattr(field.rel.to, field.related.get_accessor_name()))
                 patch_related_object_descriptor_caching(sro_descriptor)
